marktools.LilyPondComment
=========================

.. inheritance-diagram:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment
   :private-bases:

.. autoclass:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.format

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.contents_string

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.format_slot

Methods
-------

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__eq__

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__str__

   .. note:: Inherited from `__builtin__.object`
